==> string-to-numeric-0.1.0.tgz: package/index.ts <==
type DecimalSeparator = '.' | ','

export interface ParsingOptions {
  decimalSeparator: DecimalSeparator
}

/**
 * Retrieves the computer's locale decimal separator.
 * @returns Either "." or ",".
 */
export function getLocaleDecimalSeparator(): DecimalSeparator {
  return (1.1).toLocaleString().charAt(1) as DecimalSeparator
}

export const defaultParsingOptions: ParsingOptions = {
  decimalSeparator: getLocaleDecimalSeparator()
}

/**
 * Converts a string into a number.
 * @param numericString - A string representing a number.
 * @param userParsingOptions - Optional parameters.
 * @returns A numeric representation of the given string.
 */
export default function parseNumeric(
  numericString: string,
  userParsingOptions?: Partial<ParsingOptions>
): number {
  const options = Object.assign({}, defaultParsingOptions, userParsingOptions)

  let finalMultiplier = 1

  let processingString = (numericString ?? '').trim().toLowerCase()

  /*
   * Remove thousands separators
   */

  processingString =
    options.decimalSeparator === '.'
      ? numericString.replaceAll(',', '')
      : numericString.replaceAll('.', '')

  /*
   * Make decimal separator a decimal
   */

  processingString = processingString.replaceAll(',', '.')

  /*
   * Replace enclosing circle brackets with a negative sign
   */

  if (processingString.startsWith('(') && processingString.endsWith(')')) {
    processingString = processingString.slice(1, -1)
    finalMultiplier = -1
  }

  /*
   * Remove any leading units
   */

  while (processingString !== '') {
    if ('0123456789'.includes(processingString.charAt(0))) {
      break
    } else {
      if (processingString.startsWith('-')) {
        finalMultiplier = -1
      }

      processingString = processingString.slice(1)
    }
  }

  return Number.parseFloat(processingString) * finalMultiplier
}

==> string-to-numeric-0.1.1.tgz: package/index.ts <==
type DecimalSeparator = '.' | ','

export interface ParsingOptions {
  decimalSeparator: DecimalSeparator
}

/**
 * Retrieves the computer's locale decimal separator.
 * @returns Either "." or ",".
 */
export function getLocaleDecimalSeparator(): DecimalSeparator {
  return (1.1).toLocaleString().charAt(1) as DecimalSeparator
}

export const defaultParsingOptions: ParsingOptions = {
  decimalSeparator: getLocaleDecimalSeparator()
}

export function parseNumeric(numericString: undefined | null, userParsingOptions?: Partial<ParsingOptions>): undefined
export function parseNumeric(numericString: string, userParsingOptions?: Partial<ParsingOptions>): number

/**
 * Converts a string into a number.
 * @param numericString - A string representing a number.
 * @param userParsingOptions - Optional parameters.
 * @returns A numeric representation of the given string.
 */
export function parseNumeric(
  numericString: string | undefined | null,
  userParsingOptions?: Partial<ParsingOptions>
): number | undefined {
  if (numericString === undefined || numericString === null) {
    return undefined
  }

  const options = Object.assign({}, defaultParsingOptions, userParsingOptions)

  let finalMultiplier = 1

  let processingString = (numericString ?? '').trim().toLowerCase()

  /*
   * Remove thousands separators
   */

  processingString =
    options.decimalSeparator === '.'
      ? numericString.replaceAll(',', '')
      : numericString.replaceAll('.', '')

  /*
   * Make decimal separator a decimal
   */

  processingString = processingString.replaceAll(',', '.')

  /*
   * Replace enclosing circle brackets with a negative sign
   */

  if (processingString.startsWith('(') && processingString.endsWith(')')) {
    processingString = processingString.slice(1, -1)
    finalMultiplier = -1
  }

  /*
   * Remove any leading units
   */

  while (processingString !== '') {
    if ('0123456789'.includes(processingString.charAt(0))) {
      break
    } else {
      if (processingString.startsWith('-')) {
        finalMultiplier = -1
      }

      processingString = processingString.slice(1)
    }
  }

  return Number.parseFloat(processingString) * finalMultiplier
}


export default parseNumeric
